void
init();

void
pre_init();

void
settings_set_repolist();
